AnchorKey class

Inheritance

Properties

currentContext → BuildContext?
The build context in which the widget with this key builds.
no setterinherited
currentState → State<StatefulWidget>?
The State for the widget in the tree that currently has this global key.
no setterinherited
currentWidget → Widget?
The widget in the tree that currently has this global key.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
id → String
final
parentKey → Key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

forId(Key? parentKey, String? id) → AnchorKey?
of(Key? parentKey, StyledElement? id) → AnchorKey?