Margins class

Constructors

Margins({Margin? left, Margin? right, Margin? top, Margin? bottom})
const
Margins.all(double value, {Unit? unit})
Analogous to EdgeInsets.all
Margins.only({double? left, double? right, double? top, double? bottom, Unit? unit})
Analogous to EdgeInsets.only
Margins.symmetric({double? horizontal, double? vertical, Unit? unit})
Analogous to EdgeInsets.symmetric

Properties

bottom → Margin?
final
hashCode → int
The hash code for this object.
no setterinherited
left → Margin?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → Margin?
final

Methods

collapse() → Margins
Auto margins already have a "value" of zero so can be considered collapsed.
copyWith({Margin? left, Margin? right, Margin? top, Margin? bottom}) → Margins
copyWithEdge({double? left, double? right, double? top, double? bottom}) → Margins
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

zero → Margins
Analogous to EdgeInsets.zero
no setter